{% extends "allianceauth/base-bs5.html" %}

{% comment %}Remove the default "Add Character" and "Swap Main" links from the header nav{% endcomment %}
{% block header_nav_user_character_control %}{% endblock %}
