@media all {
    .aa-sovtimer .aa-sovtimer-timer-elapsed {
        color: rgb(253 126 20);
        text-shadow: 1px 1px 1px rgb(255 0 0 / 30%);
    }

    .aa-sovtimer-active-campaign,
    #aa-sovtimer-filter-active-campaigns.aa-sovtimer-filter-active,
    #aa-sovtimer-filter-active-campaigns.aa-sovtimer-filter-active small {
        color: var(--bs-table-color);

        --bs-table-active-bg: rgb(240 111 107);
        --bs-table-bg: var(--bs-danger);
        --bs-table-border-color: rgb(241 127 124);
        --bs-table-hover-bg: rgb(239 107 103);
        --bs-table-striped-bg: rgb(239 103 99 / 25%);
    }

    .aa-sovtimer-active-campaign td,
    #aa-sovtimer-filter-active-campaigns.aa-sovtimer-filter-active {
        background-color: rgb(239 103 99 / 25%) !important;
    }

    .aa-sovtimer #aa-sovtimer-filter-active-campaigns.aa-sovtimer-filter-active small {
        background-color: transparent !important;
    }

    #aa-sovtimer-filter-active-campaigns.aa-sovtimer-filter-active,
    .aa-sovtimer #aa-sovtimer-filter-active-campaigns.aa-sovtimer-filter-active * {
        color: var(--white) !important;
    }

    .aa-sovtimer-upcoming-campaign {
        color: var(--bs-table-color) !important;

        --bs-table-active-bg: rgb(249 159 31);
        --bs-table-bg: var(--bs-warning);
        --bs-table-border-color: rgb(249 169 56);
        --bs-table-hover-bg: rgb(249 156 25);
        --bs-table-striped-bg: rgb(248 153 18 / 25%);
    }

    .aa-sovtimer-upcoming-campaign td,
    #aa-sovtimer-filter-upcoming-campaigns.aa-sovtimer-filter-active {
        background-color: rgb(248 148 6 / 25%) !important;
    }

    #aa-sovtimer-filter-upcoming-campaigns.aa-sovtimer-filter-active,
    .aa-sovtimer #aa-sovtimer-filter-upcoming-campaigns.aa-sovtimer-filter-active * {
        color: var(--white) !important;
    }

    .aa-sovtimer #aa-sovtimer-filter-upcoming-campaigns.aa-sovtimer-filter-active small {
        background-color: transparent !important;
        color: var(--bs-secondary-color) !important
    }

    .table-striped.aa-sovtimer-campaigns > tbody > tr:nth-of-type(odd) > *,
    .table-striped.aa-sovtimer-campaigns > tbody > tr:nth-of-type(even) > * {
        background-color: var(--bs-table-striped-bg) !important;

        --bs-table-color-type: var(--bs-table-striped-color) !important;
    }
}
