@media all {
    .aa-srp .card-srp-request-bulk-actions {
        --background-color-light-transparency: rgb(58 63 68 / 95%);

        background-color: var(--background-color-light-transparency) !important;
    }
}
